==> hermes-2.5.3.60.tar.gz: hermes-2.5.3.60/app/serializers/hermes/required_document_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class RequiredDocumentSerializer < Hermes::ApplicationSerializer
    cache key: proc { "#{object.cache_key}" }, expires_in: 1.day
    type 'required_documents'

    attributes :nature,
               :type,
               :label,
               :type_ihm,
               :metas,
               :validity_limit,
               :is_still_valid,
               :validation_errors,
               :tagset_id,
               :tagsetLocation,
               :files,
               :category,
               :is_required_for_nud,
               :is_required_for_consultation,
               :is_required_for_application,
               :is_for_main_applicant,
               :dependent_infos,
               :disability_index,
               :applicant,
               :ihm_order,    
               :last_xml_validation_report,
               :last_send_has_error,
               :status,
               :status_id,
               :status_updated_at,
               :old_status,
               :status_history,
               :kyc_needed,
               :or_required_document_types

   attribute :metas, key_transformation: :unaltered
     def tagset_id
       object&.tagset_id
     end
    def check_if_new_name(type)
      new_name_hash = {
        "Avis d'imposition N-1" => "Avis d'imposition 2021 sur les revenus de l'année 2020" ,
        "Avis d'imposition N-2" => "Avis d'imposition 2020 sur les revenus de l'année 2019" ,
      }
        new_name_hash[type] || type
    end
    def status
      object.status_regarding_validity_limit  unless @instance_options[:hide_status]
    end
    
   def is_still_valid
     !!object.validity_limit && object.validity_limit > DateTime.now.to_date
   end
   
   def status_history
     Hermes::Status.where(object_id: object.id).limit(5).order_by(created_at: -1)  unless @instance_options[:hide_status]
   end
    
    def type
      splitted_type = object.type.split("####")
    
      if (splitted_type[1])
        check_if_new_name(splitted_type[1])
      else
        splitted_type2 = object.type.split("****")
        if (splitted_type2[1])
          check_if_new_name(splitted_type2[1])
        else
          check_if_new_name(object.type)
          end
      end
    end

    def current_user_roles
      scope.attributes.slice(:roles, :auth_roles).values.flatten.uniq.compact
    end
    
    def dependent_infos
      splitted_type = object.type.split("####")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    
    def disability_index
      splitted_type = object.type.split("****")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    def files
      return unless object.doc_id
      res = []
      doc = Doc.find(object.doc_id)
      return unless doc
      res.push({
                 doc_id: object.doc_id.to_s,
                 filename: doc.title,
                 url: object.hermes_ged_link(object.file_url),
                 preview_url: object.hermes_ged_link(object.preview_url),
                 doc_data: object.smartify_urls(object.get_ged_doc_data)
               })
      res
    end
    
    def is_required_for_nud
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_nud.include? (folder_id)
    end
    
    def is_required_for_consultation
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_consultation.include? (folder_id)
    end
    
    def is_required_for_application
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_application.include? (folder_id)
    end
    
    def is_for_main_applicant
      main_applicant_id = instance_options[:main_applicant_id]
      return unless main_applicant_id
      
      (object.applicant.id.to_s == main_applicant_id.to_s)
    end
    
    def applicant
      return nil unless object.applicant
      Hermes::ApplicantSerializer.new(
        object.applicant,
        scope: scope,
        root: false
      )
    end
  end
end

==> hermes-2.5.3.61.tar.gz: hermes-2.5.3.61/app/serializers/hermes/required_document_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class RequiredDocumentSerializer < Hermes::ApplicationSerializer
    cache key: proc { "#{object.cache_key}" }, expires_in: 1.day
    type 'required_documents'

    attributes :nature,
               :type,
               :label,
               :type_ihm,
               :metas,
               :validity_limit,
               :is_still_valid,
               :validation_errors,
               :tagset_id,
               :tagsetLocation,
               :files,
               :category,
               :is_required_for_nud,
               :is_required_for_consultation,
               :is_required_for_application,
               :is_for_main_applicant,
               :dependent_infos,
               :disability_index,
               :applicant,
               :ihm_order,    
               :last_xml_validation_report,
               :last_send_has_error,
               :status,
               :status_id,
               :status_updated_at,
               :old_status,
               :status_history,
               :kyc_needed,
               :or_required_document_types,
               :declared

   attribute :metas, key_transformation: :unaltered
     def tagset_id
       object&.tagset_id
     end
    def check_if_new_name(type)
      new_name_hash = {
        "Avis d'imposition N-1" => "Avis d'imposition 2021 sur les revenus de l'année 2020" ,
        "Avis d'imposition N-2" => "Avis d'imposition 2020 sur les revenus de l'année 2019" ,
      }
        new_name_hash[type] || type
    end
    def status
      object.status_regarding_validity_limit  unless @instance_options[:hide_status]
    end
    
   def is_still_valid
     !!object.validity_limit && object.validity_limit > DateTime.now.to_date
   end
   
   def status_history
     Hermes::Status.where(object_id: object.id).limit(5).order_by(created_at: -1)  unless @instance_options[:hide_status]
   end
    
    def type
      splitted_type = object.type.split("####")
    
      if (splitted_type[1])
        check_if_new_name(splitted_type[1])
      else
        splitted_type2 = object.type.split("****")
        if (splitted_type2[1])
          check_if_new_name(splitted_type2[1])
        else
          check_if_new_name(object.type)
          end
      end
    end

    def current_user_roles
      scope.attributes.slice(:roles, :auth_roles).values.flatten.uniq.compact
    end
    
    def dependent_infos
      splitted_type = object.type.split("####")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    
    def disability_index
      splitted_type = object.type.split("****")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    def files
      return unless object.doc_id
      res = []
      doc = Doc.find(object.doc_id)
      return unless doc
      res.push({
                 doc_id: object.doc_id.to_s,
                 filename: doc.title,
                 url: object.hermes_ged_link(object.file_url),
                 preview_url: object.hermes_ged_link(object.preview_url),
                 doc_data: object.smartify_urls(object.get_ged_doc_data)
               })
      res
    end
    
    def is_required_for_nud
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_nud.include? (folder_id)
    end
    
    def is_required_for_consultation
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_consultation.include? (folder_id)
    end
    
    def is_required_for_application
      folder_id = instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_application.include? (folder_id)
    end
    
    def is_for_main_applicant
      main_applicant_id = instance_options[:main_applicant_id]
      return unless main_applicant_id
      
      (object.applicant.id.to_s == main_applicant_id.to_s)
    end
    
    def applicant
      return nil unless object.applicant
      Hermes::ApplicantSerializer.new(
        object.applicant,
        scope: scope,
        root: false
      )
    end
  end
end
